==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/sv.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "sv", 
    "plural-forms": "nplurals=2; plural=(n != 1);"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "", 
    ""
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "", 
    ""
  ], 
  "Add Filter": [
    null, 
    "Lägg till filter"
  ], 
  "An Error Occurred": [
    null, 
    "Ett fel uppstod"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Vill du verkligen genomföra denna åtgärd?"
  ], 
  "Cancel": [
    null, 
    "Avbryt"
  ], 
  "Confirm": [
    null, 
    "Bekräfta"
  ], 
  "Edit": [
    null, 
    "Redigera"
  ], 
  "Failed to load data API information": [
    null, 
    "Misslyckades med att ladda API-information"
  ], 
  "File": [
    null, 
    "Fil"
  ], 
  "Filters": [
    null, 
    "Filter"
  ], 
  "Follow": [
    null, 
    "Följ"
  ], 
  "Graph": [
    null, 
    "Graf"
  ], 
  "Hide": [
    null, 
    "Dölj"
  ], 
  "Image": [
    null, 
    "Bild"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "", 
    ""
  ], 
  "Link": [
    null, 
    "Länk"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Länk till en URL på internet (du kan också länka till ett API)"
  ], 
  "Loading...": [
    null, 
    "Laddar..."
  ], 
  "Map": [
    null, 
    "Karta"
  ], 
  "No matches found": [
    null, 
    "Hittades inte"
  ], 
  "Please Confirm Action": [
    null, 
    "Vänligen Bekräfta Åtgärd"
  ], 
  "Remove": [
    null, 
    "Radera"
  ], 
  "Resource uploaded": [
    null, 
    "Resursen laddades upp"
  ], 
  "Save order": [
    null, 
    "Spara ordning"
  ], 
  "Saving...": [
    null, 
    "Sparar..."
  ], 
  "Show more": [
    null, 
    "Visa mer"
  ], 
  "Start typing…": [
    null, 
    "Börja skriv..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Det finns ändringar i detta formulär som inte sparats"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Det finns inga API-data att ladda för denna resurs"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Kunde inte verifiera behörighet för uppladdningen"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Kunde inte läsa data i den uppladdade filen"
  ], 
  "Unable to upload file": [
    null, 
    "Kunde inte ladda upp filen"
  ], 
  "Unfollow": [
    null, 
    "Sluta följa"
  ], 
  "Upload": [
    null, 
    "Ladda upp"
  ], 
  "Upload a file": [
    null, 
    "Ladda upp en fil"
  ], 
  "Upload a file on your computer": [
    null, 
    "Ladda upp en fil från din dator"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Du laddar upp en fil. Är du säker på att du vill lämna sidan och avbryta uppladdningen?"
  ], 
  "bar": [
    "bars", 
    "", 
    ""
  ], 
  "error loading view": [
    null, 
    "Fel vid laddning av vy"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "", 
    ""
  ], 
  "no translation": [
    "no translations", 
    "", 
    ""
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/sv.js <==
{
  "": {
    "domain": "ckan",
    "lang": "sv",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "Add Filter": [
    null,
    "Lägg till filter"
  ],
  "An Error Occurred": [
    null,
    "Ett fel uppstod"
  ],
  "An error occured during AJAX request. Could not load view.": [
    null,
    "Ett fel uppstod i en AJAX förfrågan. Kan inte ladda vy."
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Vill du verkligen genomföra denna åtgärd?"
  ],
  "Cancel": [
    null,
    "Avbryt"
  ],
  "Confirm": [
    null,
    "Bekräfta"
  ],
  "Could not load view": [
    null,
    "Kunde inte ladda vy"
  ],
  "DataProxy returned an error": [
    null,
    "DataProxy rapporterade ett fel"
  ],
  "DataStore returned an error": [
    null,
    "DataStore rapporterade ett fel"
  ],
  "Edit": [
    null,
    "Redigera"
  ],
  "Failed to load data API information": [
    null,
    "Misslyckades med att ladda API-information"
  ],
  "File": [
    null,
    "Fil"
  ],
  "Filters": [
    null,
    "Filter"
  ],
  "Follow": [
    null,
    "Följ"
  ],
  "Graph": [
    null,
    "Graf"
  ],
  "Grid": [
    null,
    "Tabell"
  ],
  "Hide": [
    null,
    "Dölj"
  ],
  "Image": [
    null,
    "Bild"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "För kort inmatning, måste vara åtminstone ett tecken",
    "För kort inmatning, måste vara åtminstone %(num)d tecken"
  ],
  "Link": [
    null,
    "Länk"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Länk till en URL på internet (du kan också länka till ett API)"
  ],
  "Loading...": [
    null,
    "Laddar..."
  ],
  "Map": [
    null,
    "Karta"
  ],
  "No matches found": [
    null,
    "Hittades inte"
  ],
  "Please Confirm Action": [
    null,
    "Vänligen Bekräfta Åtgärd"
  ],
  "Please select the file to upload again": [
    null,
    "Välj fil att ladda upp igen"
  ],
  "Remove": [
    null,
    "Ta bort"
  ],
  "Reorder resources": [
    null,
    "Ändra ordning på resurser"
  ],
  "Resource uploaded": [
    null,
    "Resursen laddades upp"
  ],
  "Save order": [
    null,
    "Spara ordning"
  ],
  "Saving...": [
    null,
    "Sparar..."
  ],
  "Select a field": [
    null,
    "Välj ett fält"
  ],
  "Show more": [
    null,
    "Visa mer"
  ],
  "Start typing…": [
    null,
    "Börja skriv..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Det finns ändringar i detta formulär som inte sparats"
  ],
  "There is no API data to load for this resource": [
    null,
    "Det finns inga API-data att ladda för denna resurs"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Kunde inte verifiera behörighet för uppladdningen"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Kunde inte läsa data i den uppladdade filen"
  ],
  "Unable to upload file": [
    null,
    "Kunde inte ladda upp filen"
  ],
  "Unfollow": [
    null,
    "Sluta följa"
  ],
  "Upload": [
    null,
    "Ladda upp"
  ],
  "Upload a file": [
    null,
    "Ladda upp en fil"
  ],
  "Upload a file on your computer": [
    null,
    "Ladda upp en fil från din dator"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Du laddar upp en fil. Är du säker på att du vill lämna sidan och avbryta uppladdningen?"
  ],
  "You can rearrange the resources by dragging them using the arrow icon. Drag the resource to the right and place it to the desired location on the list. When you are done, click the \"Save order\" -button.": [
    null,
    "Du kan ändra ordning på resurser genom att dra dem med pil-ikonen. Dra resursen något till höger och placera i önskad ordning direkt i listan. När du är klar, klicka på \"Spara ordning\" knappen."
  ],
  "error loading view": [
    null,
    "Fel vid laddning av vy"
  ]
}
